==> EspoCRM-4.0.2.zip: EspoCRM-4.0.2/client/src/views/stream/fields/post.js <==
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM - Open Source CRM application.
 * Copyright (C) 2014-2015 Yuri Kuznetsov, Taras Machyshyn, Oleksiy Avramenko
 * Website: http://www.espocrm.com
 *
 * EspoCRM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EspoCRM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EspoCRM. If not, see http://www.gnu.org/licenses/.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
 ************************************************************************/

Espo.define('Views.Stream.Fields.Post', 'Views.Fields.Text', function (Dep) {

    return Dep.extend({

        getValueForDisplay: function () {
            var text = Dep.prototype.getValueForDisplay.call(this);

            if (this.mode == 'detail' || this.mode == 'list') {
                var mentionData = (this.model.get('data') || {}).mentions || {};

                Object.keys(mentionData).sort(function (a, b) {
                    return a.length < b.length
                }).forEach(function (item) {
                    var part = '(' + mentionData[item].name + ')[#User/view/'+mentionData[item].id + ']';
                    text = text.replace(new RegExp(item, 'g'), part);
                });
            }

            return text;
        },

    });

});

==> EspoCRM-5.8.2.zip: EspoCRM-5.8.2/client/src/views/stream/fields/post.js <==
/************************************************************************
 * This file is part of EspoCRM.
 *
 * EspoCRM - Open Source CRM application.
 * Copyright (C) 2014-2020 Yuri Kuznetsov, Taras Machyshyn, Oleksiy Avramenko
 * Website: https://www.espocrm.com
 *
 * EspoCRM is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * EspoCRM is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with EspoCRM. If not, see http://www.gnu.org/licenses/.
 *
 * The interactive user interfaces in modified source and object code versions
 * of this program must display Appropriate Legal Notices, as required under
 * Section 5 of the GNU General Public License version 3.
 *
 * In accordance with Section 7(b) of the GNU General Public License version 3,
 * these Appropriate Legal Notices must retain the display of the "EspoCRM" word.
 ************************************************************************/

define('views/stream/fields/post', 'views/fields/text', function (Dep) {

    return Dep.extend({

        getValueForDisplay: function () {
            var text = Dep.prototype.getValueForDisplay.call(this);

            if (this.mode == 'detail' || this.mode == 'list') {
                var mentionData = (this.model.get('data') || {}).mentions || {};

                Object.keys(mentionData).sort(function (a, b) {
                    return a.length < b.length
                }).forEach(function (item) {
                    var part = '[' + mentionData[item].name + '](#User/view/'+mentionData[item].id + ')';
                    text = text.replace(new RegExp(item, 'g'), part);
                }.bind(this));
            }

            return text;
        },

    });

});
